ServerClient

Struct ServerClient 

pub struct ServerClient<'a> { /* private fields */ }

Implementations

Source

impl<'a> ServerClient<'a>

pub fn new(api_client: &'a Client) -> Self

pub async fn list(&self) -> Result<Vec<Server>, Error>

List all servers

200 OK – An array of servers Returns: array of Server objects

400 Bad Request – The supplied request was not valid Returns: Error object

404 Not Found – Requested item was not found Returns: Error object

422 Unprocessable Entity – The input to the operation was not valid Returns: Error object

500 Internal Server Error – Internal server error Returns: Error object

pub async fn get(&self, server_id: &str) -> Result<Server, Error>

List a server

Arguments
  • server_id - The id of the server to retrieve

200 OK – An server Returns: Server object

400 Bad Request – The supplied request was not valid Returns: Error object

404 Not Found – Requested item was not found Returns: Error object

422 Unprocessable Entity – The input to the operation was not valid Returns: Error object

500 Internal Server Error – Internal server error Returns: Error object